@@ -4,7 +4,7 @@
 # test_die.py
 # Part of alea, a library of random generators for games
 #
-# Copyright © 2007 Ben Finney <ben@benfinney.id.au>
+# Copyright © 2007 Ben Finney <ben+python@benfinney.id.au>
 # This is free software; you may copy, modify and/or distribute this work
 # under the terms of the GNU General Public License, version 2 or later.
 # No warranty expressed or implied. See the file LICENSE for details.
@@ -239,7 +239,7 @@ class RollResultFixture(RollerFixture):
                     roller = self.valid_rollers['3d6']['instance'],
                     faces = [6,6,6],
                 ),
-                total = 36,
+                total = 18,
             ),
         }
 
@@ -306,7 +306,7 @@ class Test_Die(unittest.TestCase, DieFixture):
             instance = params['instance']
             self.failUnlessEqual(is_numeric, instance.is_numeric())
 
-    def test_roll(self):
+    def test_roll_is_within_faces_set(self):
         """ Die result should be one of the specified faces """
         for key, params in self.iterate_params():
             args = params['args']
@@ -387,11 +387,12 @@ class Test_Roller(unittest.TestCase, RollerFixture):
         """ Roller should export its numeric total range """
         for key, params in self.iterate_params():
             args = params['args']
-            if 'total_range' not in args:
-                continue
             instance = params['instance']
+            total_range = args.get('total_range')
+            if total_range is None:
+                total_range = instance.modified_dice_range
             self.failUnlessEqual(
-                args['total_range'], instance.total_range
+                total_range, instance.total_range
             )
 
     def test_modified_dice_range(self):
@@ -416,8 +417,8 @@ class Test_Roller(unittest.TestCase, RollerFixture):
             if not is_numeric:
                 continue
             dice = args['dice']
-            dice_range_min = sum([min(d.faces) for d in dice])
-            dice_range_max = sum([max(d.faces) for d in dice])
+            dice_range_min = sum(min(d.faces) for d in dice)
+            dice_range_max = sum(max(d.faces) for d in dice)
             modifier = args.get('modifier', 0)
             modified_dice_range = range(
                 dice_range_min + modifier,
@@ -427,9 +428,9 @@ class Test_Roller(unittest.TestCase, RollerFixture):
             instance = params['instance']
             for i in range(len(instance.total_range) * 10):
                 result = instance.get_result()
-                self.failUnless(result.total() in total_range,
+                self.failUnless(result.total in total_range,
                     msg = "%d not in %s" % (
-                        result.total(), total_range
+                        result.total, total_range
                     )
                 )
 
@@ -443,9 +444,9 @@ class Test_Roller(unittest.TestCase, RollerFixture):
             instance = params['instance']
             for i in range(len(instance.total_range) * 10):
                 result = instance.get_result()
-                self.failUnless(result.total() in total_range,
+                self.failUnless(result.total in total_range,
                     msg = "%s not in %s" % (
-                        result.total(), total_range
+                        result.total, total_range
                     )
                 )
 
@@ -502,18 +503,22 @@ class Test_RollResult(unittest.TestCase, RollResultFixture):
             instance = params['instance']
             self.failUnlessEqual(args['faces'], instance.faces)
 
-    def test_total(self):
+    def test_total_equal(self):
         """ RollResult should determine its numeric total """
         for key, params in self.iterate_params():
             args = params['args']
             roller = args['roller']
             if not roller.is_numeric():
                 continue
-            total = sum(args['faces']) + roller.modifier
-            total = min(total, min(roller.total_range))
-            total = max(total, max(roller.total_range))
+            total = params['total']
             instance = params['instance']
-            self.failUnlessEqual(total, instance.total())
+            instance_total = instance.total
+            roller_total_range = instance.roller.total_range
+            self.failUnlessEqual(total, instance.total,
+                "%(instance)r (total range %(roller_total_range)r):"
+                " expect total %(total)r, instead got %(instance_total)r"
+                    % locals()
+            )
 
 
 suite = scaffold.suite(__name__)
